nll <-
function( cparams, y0, y , nLL, nSL)
 {
  ## negative log likelihood; integrates three data sources
  ##
  ## y0: control log lifespans
  ## y; mutagenesis  log lifespans
  ## nLL, nSL; counts, directional information on confirmed modifiers
  ##
  ## cparams [mu0, muD, sigma0, sigmaLL, sigmaSL , p0, pLL]
  ##
  mu0 <- cparams[1]
  muD <- cparams[2]
  sigma0 <- cparams[3]
  sigmaLL <- cparams[4]
  sigmaSL <- cparams[5]
  mprop <- c( cparams[6], cparams[7], 1-cparams[6]-cparams[7]) 
  
  ## contribution from control animals
  lcontrol <- sum( dnorm( y0, mean=mu0, sd=sigma0, log=TRUE  )  )

  ## component contributions in mutagenized sample
  tmp0 <- dnorm( y, mean=mu0, sd=sigma0, log=TRUE ) 
  tmpLL <- .ldenLL( y, mu0=mu0, muD=muD, 
		sigma0=sigma0, sigmaLL=sigmaLL ) 
  tmpSL <- .ldenSL( y, mu0=mu0, muD=muD, 
		sigma0=sigma0, sigmaSL=sigmaSL )
 
  pmix <- mprop[1] * exp(tmp0) + mprop[2] *exp(tmpLL) + mprop[3] *exp( tmpSL )
  bar <- lcontrol + sum(  log(pmix)  )

  # add in the Kwong/Dove component ... info on mixing proportions
  kw <- nLL * log( mprop[2] ) + nSL * log(mprop[3] ) -
                (nLL+nSL)*log(mprop[2]+mprop[3])
  return(-(bar+kw) )
 }
