#
#We picked kindreds that had members dying before 90% (<=143 days) 
#
#Kindred 333: 7 short-lived/8 total
#Kindred 415: 3 short-lived/3 total
clow <- (143)  

## following cmixfit6, work out P[ fold effects > such and such | selection ] for various selection as in real mt study


data(ENU)

y <- log(ENU$G1F1$LastAge)  ## #log survival times, mutagenized
y0 <- log(ENU$F1)   ## same, controls

## Data from Table 3 of Kwong and Dove
nLL <- 10  ## mutants that reduced tumor burden
nSL <- 21  ## mutants that increased tumor burden

# fit
fit <- nlminb( start=c(5.2, 0.2, 0.17, 0.5, 0.8, 0.7, 0.2) ,
                objective=nll, y0=y0, y=y, nLL=nLL, nSL=nSL,
                lower=c(-Inf,0,0.01,0.01,0.01,0.5,0) )


mu0 <- fit$par[1]
sigma0 <- fit$par[3]
sigmaLL <- fit$par[4]
sigmaSL <- fit$par[5]
mprop <- numeric(3)
mprop[1] <- fit$par[6]
mprop[2] <- fit$par[7]
mprop[3] <- 1-mprop[1] - mprop[2]

## model says that lifetime X = MZ, with M ind. Z, 
## where Z ~ f0, and M=1 if no effective modifiers, else M .neq. 1
## M > 1 w.p. pLL  (long-lived)
## M < 1 w.p. pSL  (short-lived)
## and we make things parametrix by having log(Z) ~ Normal[ mu0, sigma0^2 ]
## log M | LL ~ Normal[ 0, sigmaLL^2 ] 1[ log(M) > 0 ]
## log M | SL ~ Normal[ 0, sigmaSL^2 ] 1[ log(M) < 0 ]
##
## the M's are like lifetime accelerators, as in the accelerated failure
## time model, and the mixture structure involves constraints on the latent
## M's, so the marginal distributions of each component can be computed
## explicitly [this makes it different than the mixture of three normals]
## Also, the M's are `effects', and with estimates of sigmaLL and sigmaSL
## we can compute various probabilities of having sufficiently large effects

p0 <- mprop[1]
pLL <- mprop[2]
pSL <- mprop[3]

## at the kindred level...what fraction of kindreds carry LL vs kindreds carry SL vs 0??

pLkin <- 2*pLL
pSkin <- 2*pSL
p0kin <- 1-pLkin-pSkin

##fsupp <- seq(1,10,length=100)  ## fold change support
##margpL <- 2*pLkin*pnorm( log(fsupp)/sigmaLL, lower.tail=FALSE )  ## marginal prob that fold M exceeds f, f >1 (i.e. LL class)
## a trick is to compute the probabilty of SEL for each family
## SEL[333] = [at least 4/8 lifetimes exceed chigh]  for example
## P[ M > f | SEL ] = int_f^infty P[m|SEL] = int_f P[SEL|m] p(m)/P[SEL]
##

psel333 <- function(logf)
	{
	## logf = logfold 
	## prob that a given animal in kindred with exp(logf) is less than clow
	foo <- (log(clow) - logf-mu0 )/sigma0
	pone <- pnorm( foo  ) 	
	pall <- 1-pbinom( q=6, size=8, prob=pone )  ## chance of at least 7/8
	pall
	}

psel415 <- function(logf)
	{
	## logf = logfold
	## prob that a given animal in kindred with exp(logf) exceeds chigh
	foo <- (log(clow) - logf-mu0 )/sigma0
	pone <- pnorm( foo  ) 	
	pall <- dbinom( x=3, size=3, prob=pone )  ## chance of at least 3/3
	pall
	}

pmarg  <- function(logf)
	{
	## marginal (mixing distribution)
	if( logf==0 )
	 { den <- p0kin  }
	if( logf < 0 )
	 { den <- 2 * pSkin * dnorm( logf, mean=0, sd=sigmaSL ) }
	if( logf > 0 )
	 { den <- 2 * pLkin * dnorm( logf, mean=0, sd=sigmaLL ) }
	den
	}

u <- seq( 0, log(10) , length=499 )
lfsupp <- unique( c( -rev(u), u ) )  ## exactly one value at 0
del <- lfsupp[2] - lfsupp[1]

pm <- numeric( length(lfsupp) )
ps333 <- pm
ps415 <- pm
for( j in 1:length(lfsupp) )
  {
   if( lfsupp[j] == 0 ){ pm[j] <- pmarg( lfsupp[j] ) }
   if( lfsupp[j] != 0 ){ pm[j] <- del*pmarg( lfsupp[j] ) }    ## dealing with the spike / slab by making it a prob mass on grid
   ps333[j] <- psel333( lfsupp[j] )
   ps415[j] <- psel415( lfsupp[j] )
  }

## P[M<f, SEL]

pjoint333 <- pm * ps333 ## P[ M==f , SEL ]  
pjoint415 <- pm * ps415 ## P[ M==f , SEL ]  
 		## so sum pjoint is P[SEL]...about 12%
pcond333 <- pjoint333/sum(pjoint333)
pcond415 <- pjoint415/sum(pjoint415)

pexceed.sel333 <- cumsum(pcond333)
pexceed.sel415 <- cumsum(pcond415)
pexceed.marg <- cumsum(pm)

## IQR's
iqr.sel333 <- numeric(2)
iqr.marg <- iqr.sel333
iqr.sel415 <- iqr.sel333
iqr.sel333[1] <- min( exp( lfsupp[pexceed.sel333 >= 0.25] ) ) 
iqr.sel333[2] <- min( exp( lfsupp[pexceed.sel333 >= 0.75] ) )
iqr.sel415[1] <- min( exp( lfsupp[pexceed.sel415 >= 0.25] ) ) 
iqr.sel415[2] <- min( exp( lfsupp[pexceed.sel415 >= 0.75] ) )
iqr.marg[1] <- min( exp( lfsupp[pexceed.marg >= 0.25] ) )
iqr.marg[2] <- min( exp( lfsupp[pexceed.marg >= 0.75] ) )

plot( exp(-lfsupp), pexceed.sel333, type="l", lwd=2, xlim=c(0,4),
		xlab="reducing effect on lifespan (fold reduction)",
	ylab="Prob[ > fold ]", col="red" , yaxs="i", xaxs="i" )
lines( exp(-lfsupp), pexceed.sel415, lwd=2, col="green" )
lines( exp(-lfsupp), pexceed.marg, lwd=2, col="blue" )
abline( v=1 )
abline( h=pSkin )
legend("topright",legend=c("marginal","given 7/8 < 143 days",
		"given 3/3 < 143 days") ,
	lwd=2, col=c("blue","red","green")  )

lines( 1/iqr.sel333, rep(0.01,2),lwd=7, col="red" )
lines( 1/iqr.marg, rep(0.01,2),lwd=7, col="blue" )
lines( 1/iqr.sel415, rep(.03,2),lwd=7, col="green" )

