
## fitting/plotting the mixture model

data(ENU)

y <- log(ENU$G1F1$LastAge)  ## #log survival times, mutagenized
y0 <- log(ENU$F1)   ## same, controls

## Data from Table 3 of Kwong and Dove
nLL <- 10  ## mutants that reduced tumor burden
nSL <- 21  ## mutants that increased tumor burden

# fit
fit <- nlminb( start=c(5.2, 0.2, 0.17, 0.5, 0.8, 0.7, 0.2) ,
		objective=nll, y0=y0, y=y, nLL=nLL, nSL=nSL,
                lower=c(-Inf,0,0.01,0.01,0.01,0.5,0) )

# plot
mu0 <- fit$par[1]
sigma0 <- fit$par[3]
sigmaLL <- fit$par[4]
sigmaSL <- fit$par[5]
mprop <- numeric(3)
mprop[1] <- fit$par[6]
mprop[2] <- fit$par[7]
mprop[3] <- 1-mprop[1] - mprop[2]

p0 <- mprop[1]
pL <- mprop[2]
pS <- mprop[3]

supp <- seq( min(y), max(y), length=200 )
denL <- numeric( length(supp) )
denS <- denL
for( i in 1:length(supp) )
 {
  denS[i] <- denSL( x=supp[i], mu0, sigma0, sigmaSL )
  denL[i] <- denLL( x=supp[i], mu0, sigma0, sigmaLL )
 }

d0 <- dnorm( supp, mean=mu0, sd=sigma0 )
marg <- p0*d0 + pL*denL + pS*denS

lw <- 5
x <- exp(y)

par( mgp=c(3,.6,0), mar=c(4,4,1,1) )
hist( x, 100, freq=FALSE, xlab="lifespan (days)", las=1, main="", lwd=(1/2), 
   col="lightgrey ",
   border="lightgrey" ) 
legend( "topright", legend=c( "n = 1525 G1F1", 
   "long-lived", "short-lived", "unaffected"), 
   lwd=c(7, rep(lw/2,3) ), lty=c(1,1,2,3),
   col=c("lightgrey","black", "black", "black" ) )

## add the fitted components
lines( exp(supp), pL*denL/exp(supp), col="black", lwd=lw/2,lty=1 )
lines( exp(supp), pS*denS/exp(supp), col="black", lwd=lw/2, lty=2 )
lines( exp(supp), p0*d0/exp(supp), col="black", lwd=lw/2, lty=3)
