\name{nll}
\alias{nll}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
negative log likelihood; three component AFT mixture for lifespan data
}
\description{
computes the negative log likelihood from three data sources for mixture model of mutagenesis lifespan data
}
\usage{
nll(cparams, y0, y, nLL, nSL)
}
\arguments{
  \item{cparams}{
   a vector holding all parameters for mixture model: mean of null component,
   mean of multiplier (i.e. additive on log scale); 
   standard deviation of null component, standard deviation of long-lived 
   multiplier; standard deviation of short-lived multiplier; null proportion
  of mixture; long-lived proportion
}
  \item{y0}{
    log lifespans from null component
}
  \item{y}{
    log lifespans from mixture
}
  \item{nLL}{
    number of known long-lived mutants
}
  \item{nSL}{
   number of known short-lived mutants
}
}
\details{
 The log likelihood integrates three pieces of data relevant to the
mixture; the F1 data (from the null), the G1F1 data (from the mixture) ,
 and data on directional ENU effects (informs the proportions)
}
\value{
 negative log likelihood, combining all data sources
}
\references{
 Dove et al. 2014, G3. Lifespan supplement.
}
\author{
Michael Newton
}

\examples{

data(ENU)
y <- log(ENU$G1F1$LastAge)  ## #log survival times, mutagenized
y0 <- log(ENU$F1)   ## same, controls

## Data from Table 3 of Kwong and Dove
nLL <- 10  ## mutants that reduced tumor burden
nSL <- 21  ## mutants that increased tumor burden

# fit
fit <- nlminb( start=c(5.2, 0.2, 0.17, 0.5, 0.8, 0.7, 0.2) ,
                objective=nll, y0=y0, y=y, nLL=nLL, nSL=nSL,
                lower=c(-Inf,0,0.01,0.01,0.01,0.5,0) )

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
